"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const needle = require("needle");
class AdoApi {
    constructor(releaseConfiguration) {
        this.releaseConfiguration = releaseConfiguration;
    }
    getAuthHeader() {
        const auth = ":" + this.releaseConfiguration.accessToken;
        const basicAuthValue = 'Basic ' + Buffer.from(auth).toString('base64');
        const headers = {
            Authorization: basicAuthValue
        };
        return headers;
    }
    getSnapshot(apiVersion = "6.0") {
        return __awaiter(this, void 0, void 0, function* () {
            let snapshotUrl = `${this.releaseConfiguration.adoServerUri}${this.releaseConfiguration.projectName}/_apis/release/releases/${this.releaseConfiguration.id}?api-version=${apiVersion}&approvalFilters=all`;
            return yield this.executeRequest(snapshotUrl);
        });
    }
    executeRequest(url) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = {
                headers: this.getAuthHeader(),
                json: true,
                follow_max: 100
            };
            return yield needle("get", url, options)
                .then((response) => {
                if (response.body.error) {
                    let errorDetail = "";
                    if (response.body.error.detail) {
                        errorDetail = response.body.error.detail;
                    }
                    throw (`Invalid Response Code ${response.statusCode} from ADO API: ${response.statusMessage} ${errorDetail}`);
                }
                return response.body;
            });
        });
    }
}
exports.default = AdoApi;
//# sourceMappingURL=ado-api.js.map