"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert = __importStar(require("assert"));
const nock = require("nock");
const ado_api_1 = __importDefault(require("../../src/api/ado-api"));
const release_environment_variables_fake_1 = require("../fakes/release-environment-variables-fake");
function testGetSnapshotFunction(releaseConfiguration) {
    return __awaiter(this, void 0, void 0, function* () {
        let structureUnderTest = new ado_api_1.default(releaseConfiguration);
        yield structureUnderTest.getSnapshot();
    });
}
function testSuccessGetSnapshotFunction(releaseConfiguration, requestPeek = () => { }) {
    let url = new URL(`${releaseConfiguration.adoServerUri}${releaseConfiguration.projectName}/_apis/release/releases/${releaseConfiguration.id}`);
    const params = new URLSearchParams({ 'api-version': '6.0', 'approvalFilters': 'all' });
    nock(url.origin)
        .get(url.pathname)
        .query(params)
        .reply(200, requestPeek);
    testGetSnapshotFunction(releaseConfiguration);
}
function testFailureGetSnapshotFunction(releaseConfiguration, arbitraryErrorMessage) {
    return __awaiter(this, void 0, void 0, function* () {
        let url = new URL(`${releaseConfiguration.adoServerUri}${releaseConfiguration.projectName}/_apis/release/releases/${releaseConfiguration.id}`);
        const params = new URLSearchParams({ 'api-version': '6.0', 'approvalFilters': 'all' });
        nock(url.origin)
            .get(url.pathname)
            .query(params)
            .reply(500, { "error": { "detail": arbitraryErrorMessage } });
        return testGetSnapshotFunction(releaseConfiguration);
    });
}
describe("ADO-Api", function () {
    let releaseConfiguration = new release_environment_variables_fake_1.ReleaseEnvironmentVariables();
    this.afterAll(function () {
        nock.restore();
    });
    describe('When getSnapshot is called', function () {
        it('should call the API with valid auth Header', function (done) {
            const auth = ":" + releaseConfiguration.accessToken;
            const basicAuthValue = 'Basic ' + Buffer.from(auth).toString('base64');
            function requestPeek() {
                //@ts-ignore this is needed for nock to work properly
                assert.equal(this.req.headers["authorization"], basicAuthValue, "invalid authorization header was built");
                done();
            }
            testSuccessGetSnapshotFunction(releaseConfiguration, requestPeek);
        });
        describe('When API returns an error', function () {
            it('should throw an exception', () => __awaiter(this, void 0, void 0, function* () {
                let arbitraryErrorMessage = "arbitraryErrorMessage";
                return testFailureGetSnapshotFunction(releaseConfiguration, arbitraryErrorMessage)
                    .then(() => {
                    assert.ok(false, "expected error");
                }, (errorMsg) => {
                    assert.ok(errorMsg.includes(arbitraryErrorMessage));
                });
            }));
        });
    });
});
//# sourceMappingURL=ado-api-tests.js.map