"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert = __importStar(require("assert"));
const tl = require("azure-pipelines-task-lib/task");
const ts_mock_imports_1 = require("ts-mock-imports");
const service_connection_1 = require("../src/service-connection");
describe("Service Connection Tests", function () {
    const arbitraryServiceConnectionName = "arbitraryServiceConnectionName";
    const arbitraryUrl = "arbitraryUrl";
    const arbitraryEndpointId = "arbitraryEndpointId";
    const arbitraryKey1 = "arbitraryKey1";
    const arbitraryKey2 = "arbitraryKey2";
    const arbitraryKey3 = "arbitraryKey3";
    const arbitraryValue1 = "arbitraryValue1";
    const arbitraryValue2 = "arbitraryValue2";
    const arbitraryValue3 = "arbitraryValue3";
    const keys = [arbitraryKey1, arbitraryKey2, arbitraryKey3];
    let getInputStub;
    beforeEach(function () {
        ts_mock_imports_1.ImportMock.mockFunction(tl, "getEndpointUrl", arbitraryUrl);
        getInputStub = ts_mock_imports_1.ImportMock.mockFunction(tl, "getInput");
        getInputStub.withArgs(arbitraryServiceConnectionName).returns(arbitraryEndpointId);
    });
    afterEach(function () {
        ts_mock_imports_1.ImportMock.restore();
    });
    describe("when newed up", function () {
        it('populates populates endpointId and URL from the task library', () => __awaiter(this, void 0, void 0, function* () {
            let structureUnderTest = new service_connection_1.ServiceConnection(arbitraryServiceConnectionName);
            assert.strictEqual(structureUnderTest.url, arbitraryUrl, "url was mutated");
            assert.strictEqual(structureUnderTest.endpointId, arbitraryEndpointId, "endpointId was mutated");
        }));
    });
    describe("when getEndpointAuthorizationParameter is called with a set of keys", function () {
        it('it returns the values from the task library', () => __awaiter(this, void 0, void 0, function* () {
            let getEndpointAuthorizationParameterStub = ts_mock_imports_1.ImportMock.mockFunction(tl, "getEndpointAuthorizationParameter");
            getEndpointAuthorizationParameterStub.withArgs(arbitraryEndpointId, arbitraryKey1, false).returns(arbitraryValue1);
            getEndpointAuthorizationParameterStub.withArgs(arbitraryEndpointId, arbitraryKey2, false).returns(arbitraryValue2);
            getEndpointAuthorizationParameterStub.withArgs(arbitraryEndpointId, arbitraryKey3, false).returns(arbitraryValue3);
            let structureUnderTest = new service_connection_1.ServiceConnection(arbitraryServiceConnectionName);
            let authParameters = structureUnderTest.getEndpointAuthorizationParameters(keys);
            assert.strictEqual(authParameters[0].key, arbitraryKey1, "unexpected key");
            assert.strictEqual(authParameters[0].value, arbitraryValue1, "unexpected key");
            assert.strictEqual(authParameters[1].key, arbitraryKey2, "unexpected key");
            assert.strictEqual(authParameters[1].value, arbitraryValue2, "unexpected key");
            assert.strictEqual(authParameters[2].key, arbitraryKey3, "unexpected key");
            assert.strictEqual(authParameters[2].value, arbitraryValue3, "unexpected key");
        }));
    });
    describe("when getEndpointAuthorizationParameter is called with no keys", function () {
        it('it returns an empty array', () => __awaiter(this, void 0, void 0, function* () {
            let structureUnderTest = new service_connection_1.ServiceConnection(arbitraryServiceConnectionName);
            let authParameters = structureUnderTest.getEndpointAuthorizationParameters([]);
            assert.ok(authParameters.length === 0, "there should be 0 records");
        }));
    });
    describe("when getEndpointDataParameter is called with a set of keys", function () {
        it('it returns the values from the task library', () => __awaiter(this, void 0, void 0, function* () {
            let getEndpointDataParameterStub = ts_mock_imports_1.ImportMock.mockFunction(tl, "getEndpointDataParameter");
            getEndpointDataParameterStub.withArgs(arbitraryEndpointId, arbitraryKey1, false).returns(arbitraryValue1);
            getEndpointDataParameterStub.withArgs(arbitraryEndpointId, arbitraryKey2, false).returns(arbitraryValue2);
            getEndpointDataParameterStub.withArgs(arbitraryEndpointId, arbitraryKey3, false).returns(arbitraryValue3);
            let structureUnderTest = new service_connection_1.ServiceConnection(arbitraryServiceConnectionName);
            let dataParameters = structureUnderTest.getEndpointDataParameters(keys);
            assert.strictEqual(dataParameters[0].key, arbitraryKey1, "unexpected key");
            assert.strictEqual(dataParameters[0].value, arbitraryValue1, "unexpected key");
            assert.strictEqual(dataParameters[1].key, arbitraryKey2, "unexpected key");
            assert.strictEqual(dataParameters[1].value, arbitraryValue2, "unexpected key");
            assert.strictEqual(dataParameters[2].key, arbitraryKey3, "unexpected key");
            assert.strictEqual(dataParameters[2].value, arbitraryValue3, "unexpected key");
        }));
    });
    describe("when getEndpointDataParameter is called with no keys", function () {
        it('it returns an empty array', () => __awaiter(this, void 0, void 0, function* () {
            let structureUnderTest = new service_connection_1.ServiceConnection(arbitraryServiceConnectionName);
            let dataParameters = structureUnderTest.getEndpointDataParameters([]);
            assert.ok(dataParameters.length === 0, "there should be 0 records");
        }));
    });
});
//# sourceMappingURL=service-connection-tests.js.map